summaryrefslogtreecommitdiff
path: root/dbaccess/source/ext
diff options
context:
space:
mode:
authorLuboš Luňák <l.lunak@suse.cz>2012-03-08 00:49:32 +0100
committerLuboš Luňák <l.lunak@suse.cz>2012-03-12 13:35:57 +0100
commit3f765e5bb2955683fc2db10f630365a4c35416d3 (patch)
tree005cbfefc4547529d7a1e416b657d44c6e1e8308 /dbaccess/source/ext
parent56e4153e2cbee8d66659e0c59690ef8911ad090a (diff)
replace usage of OUString::replace*AsciiL() with string literal overloads
Diffstat (limited to 'dbaccess/source/ext')
-rw-r--r--dbaccess/source/ext/macromigration/migrationengine.cxx21
1 files changed, 7 insertions, 14 deletions
diff --git a/dbaccess/source/ext/macromigration/migrationengine.cxx b/dbaccess/source/ext/macromigration/migrationengine.cxx
index 5bdde99a1407..5da4555fd2aa 100644
--- a/dbaccess/source/ext/macromigration/migrationengine.cxx
+++ b/dbaccess/source/ext/macromigration/migrationengine.cxx
@@ -257,9 +257,7 @@ namespace dbmm
ResId::toString(
MacroMigrationResId(
_rDocument.eType == eForm ? STR_FORM : STR_REPORT)).
- replaceFirstAsciiL(
- RTL_CONSTASCII_STRINGPARAM("$name$"),
- _rDocument.sHierarchicalName));
+ replaceFirst("$name$", _rDocument.sHierarchicalName));
return sObjectName;
}
@@ -1031,9 +1029,7 @@ namespace dbmm
sal_Int32 nOverallRange( m_aSubDocs.size() );
rtl::OUString sProgressSkeleton(
ResId::toString(MacroMigrationResId( STR_OVERALL_PROGRESS)).
- replaceFirstAsciiL(
- RTL_CONSTASCII_STRINGPARAM("$overall$"),
- rtl::OUString::valueOf(nOverallRange)));
+ replaceFirst("$overall$", rtl::OUString::valueOf(nOverallRange)));
m_rProgress.start( nOverallRange );
@@ -1045,8 +1041,7 @@ namespace dbmm
sal_Int32 nOverallProgressValue( doc - m_aSubDocs.begin() + 1 );
// update overall progress text
::rtl::OUString sOverallProgress(
- sProgressSkeleton.replaceFirstAsciiL(
- RTL_CONSTASCII_STRINGPARAM("$current$"),
+ sProgressSkeleton.replaceFirst("$current$",
::rtl::OUString::valueOf(nOverallProgressValue)));
m_rProgress.setOverallProgressText( sOverallProgress );
@@ -1938,14 +1933,12 @@ namespace dbmm
// a human-readable description of the affected library
::rtl::OUString sLibraryDescription(
ResId::toString(MacroMigrationResId(STR_LIBRARY_TYPE_AND_NAME)).
- replaceFirstAsciiL(
- RTL_CONSTASCII_STRINGPARAM("$type$"),
+ replaceFirst("$type$",
getScriptTypeDisplayName(_eScriptType)).
- replaceFirstAsciiL(
- RTL_CONSTASCII_STRINGPARAM("$library$"), _rLibraryName));
- //TODO: probably broken if first replaceFirstAsciiL can produce
+ replaceFirst("$library$", _rLibraryName));
+ //TODO: probably broken if first replaceFirst can produce
// fresh instance of "$library$" in subject string of second
- // replaceFirstAsciiL
+ // replaceFirst
InteractionHandler aHandler( m_aContext, m_xDocumentModel );
::rtl::OUString sPassword;